==> webERP4.07.10.zip: webERP4.07.10/includes/InputSerialItemsSequential.php <==
<?php
/* $Id: InputSerialItemsSequential.php 4734 2011-10-29 03:26:27Z daintree $*/
/*Input Serial Items - used for inputing serial numbers or batch/roll/bundle references
for controlled items - used in:
- ConfirmDispatchControlledInvoice.php
- GoodsReceivedControlled.php
- StockAdjustments.php
- StockTransfers.php
- CreditItemsControlled.php

*/

//we start with a batch or serial no header and need to display something for verification...
global $tableheader;

if (isset($_GET['LineNo'])){
	$LineNo = $_GET['LineNo'];
} elseif (isset($_POST['LineNo'])){
	$LineNo = $_POST['LineNo'];
}

echo '<td valign="top">';

/*Start a new table for the Serial/Batch ref input  in one column (as a sub table
then the multi select box for selection of existing bundle/serial nos for dispatch if applicable*/
//echo '<table><tr><td valign="top">';

/*in the first column add a table for the input of newies */
echo '<table>';
echo $tableheader;


echo '<form action="' . htmlspecialchars($_SERVER['PHP_SELF']) . '" method="post">
      <input type="hidden" name="FormID" value="' . $_SESSION['FormID'] . '" />
      <input type="hidden" name="LineNo" value="' . $LineNo . '">
      <input type="hidden" name="StockID" value="' . $StockID . '">
      <input type="hidden" name="EntryType" value="SEQUENCE">';
if ( isset($_GET['EditControlled']) ) {
	$EditControlled = isset($_GET['EditControlled'])?$_GET['EditControlled']:false;
} elseif ( isset($_POST['EditControlled']) ){
	$EditControlled = isset($_POST['EditControlled'])?$_POST['EditControlled']:false;
}
echo '<tr>
		<td valign="top">'. _('Begin:') . '</td>
		<td> <input type="text" name="BeginNo" size="21"  maxlength="20" value="'. $_POST['BeginNo']. '" /></td>
	</tr>';
echo '<tr>
		<td valign="top">'. _('End:') . '</td>
		<td> <input type="text" name="EndNo" size="21"  maxlength="20"  value="'. $_POST['EndNo']. '" /></td>
	</tr>';

echo '</table>';
echo '<br /><center><input type="submit" name="AddSequence" value="'. _('Enter'). '"></center><br />';
echo '</form></td><td valign="top">';
//echo '</td></tr></table>'; /*end of nested table */
?>

==> webERP4.08.4.zip: webERP4.08.4/includes/InputSerialItemsSequential.php <==
<?php
/* $Id: InputSerialItemsSequential.php 4950 2012-02-22 06:26:38Z daintree $*/
/*Input Serial Items - used for inputing serial numbers or batch/roll/bundle references
for controlled items - used in:
- ConfirmDispatchControlledInvoice.php
- GoodsReceivedControlled.php
- StockAdjustments.php
- StockTransfers.php
- CreditItemsControlled.php

*/

//we start with a batch or serial no header and need to display something for verification...
global $tableheader;

if (isset($_GET['LineNo'])){
	$LineNo = $_GET['LineNo'];
} elseif (isset($_POST['LineNo'])){
	$LineNo = $_POST['LineNo'];
}

echo '<td valign="top">';

/*Start a new table for the Serial/Batch ref input  in one column (as a sub table
then the multi select box for selection of existing bundle/serial nos for dispatch if applicable*/
//echo '<table><tr><td valign="top">';

/*in the first column add a table for the input of newies */
echo '<table>';
echo $tableheader;


echo '<form action="' . htmlspecialchars($_SERVER['PHP_SELF'],ENT_QUOTES,'UTF-8') . '" method="post">
      <input type="hidden" name="FormID" value="' . $_SESSION['FormID'] . '" />
      <input type="hidden" name="LineNo" value="' . $LineNo . '">
      <input type="hidden" name="StockID" value="' . $StockID . '">
      <input type="hidden" name="EntryType" value="SEQUENCE">';
if ( isset($_GET['EditControlled']) ) {
	$EditControlled = isset($_GET['EditControlled'])?$_GET['EditControlled']:false;
} elseif ( isset($_POST['EditControlled']) ){
	$EditControlled = isset($_POST['EditControlled'])?$_POST['EditControlled']:false;
}
echo '<tr>
		<td valign="top">'. _('Begin:') . '</td>
		<td> <input type="text" name="BeginNo" size="21"  maxlength="20" value="'. $_POST['BeginNo']. '" /></td>
	</tr>';
echo '<tr>
		<td valign="top">'. _('End:') . '</td>
		<td> <input type="text" name="EndNo" size="21"  maxlength="20"  value="'. $_POST['EndNo']. '" /></td>
	</tr>';

echo '</table>';
echo '<br /><center><input type="submit" name="AddSequence" value="'. _('Enter'). '"></center><br />';
echo '</form></td><td valign="top">';
//echo '</td></tr></table>'; /*end of nested table */
?>
